#include <gtk/gtk.h>


void
on_window_destroy                      (GtkObject       *object,
                                        gpointer         user_data);

void
on_page0_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page0_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page1_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page1_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page2_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page2_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page3_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page3_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page4_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page4_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page5_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page5_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page6_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page6_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page7_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page7_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page8_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page8_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page9_cancel_button_clicked         (GtkButton       *button,
                                        gpointer         user_data);

void
on_page9_install_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page10_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page10_install_button_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_page11_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page11_install_button_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_page12_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page12_install_button_clicked       (GtkButton       *button,
                                        gpointer         user_data);

void
on_page13_cancel_button_clicked        (GtkButton       *button,
                                        gpointer         user_data);

void
on_page13_install_button_clicked       (GtkButton       *button,
                                        gpointer         user_data);
